@@ -62,12 +62,12 @@ app.layout = dbc.Container([html.Br(),
     (html.Div(id='my-output')),
     html.Div(id='dummy'),
     loading(html.Div(id='loadig')),
-    dbc.Tooltip('Show marked publications', target="check-all"),
-    dbc.Tooltip('Select conference name',target="select"),
-    dbc.Tooltip('Select maximum results',target="select_max"),
-    dbc.Tooltip('Select matching algorithm',target="select_option"),
-    dbc.Tooltip('Sort by', target="select_sort"),
-    dbc.Tooltip('Show results based on code availability', target="code_option"),
+    dbc.Tooltip('Show marked publications', target="check-all", placement = 'left'),
+    dbc.Tooltip('Select conference name',target="select", placement = 'left'),
+    #dbc.Tooltip('Select maximum results',target="select_max", placement = 'left'),
+    #dbc.Tooltip('Select matching algorithm',target="select_option", placement = 'left'),
+    #dbc.Tooltip('Sort by', target="select_sort", placement = 'left'),
+    dbc.Tooltip('Show results based on code availability', target="code_option", placement = 'left'),
 
 ], style =  {'align':'center', 'width':'800px'})
 
